@@ -1,5 +1,5 @@
 # Automated Enrollment manager
-# $Id: Enrollment.pm,v 1.33 2007/03/02 21:38:18 raeburn Exp $
+# $Id: Enrollment.pm,v 1.34 2007/05/11 01:48:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -428,7 +428,6 @@ sub update_LC {
     if ($switchcount > 0) {
         if ($context eq "updatenow") {
             $switchresult = substr($switchresult,0,rindex($switchresult,"<li>"));
-            print STDERR &mt("[quant,_1,student]",$switchcount)."\n"; 
             $switchresult = &mt("The following [quant,_1,student] switched sections in this LON-CAPA course:",$switchcount).'<br/><ul><li>'.$switchresult.'</ul><br/><br/>';
         } else {
             $switchresult = &mt("The following [quant,_1,student] switched sections in this LON-CAPA course:",$switchcount)."\n\n".$switchresult."\n\n";
@@ -492,7 +491,7 @@ sub create_newuser {
             }
         }
     } elsif ($auth eq "localauth") {
-        ($authparam,$create_passwd,$authchk) = &Apache::lonnet::auto_create_password($crs,$cdom,$authparam);
+        ($authparam,$create_passwd,$authchk) = &Apache::lonnet::auto_create_password($crs,$cdom,$authparam,$udom);
     } elsif ($auth =~ m/^krb/) {
         if ($authparam eq '') {
             $$logmsg .= &mt('No Kerberos domain was provided for the new user - [_1], so the new user was not enrolled in the course',$uname).$linefeed;
@@ -501,7 +500,7 @@ sub create_newuser {
     } else {
         $authchk = 'invalid';
         $$logmsg .= &mt('An invalid authentication type was provided for the new user - [_1], so the user was not enrolled in the course.',$uname).$linefeed;
-    }   
+    }
     if ($authchk eq 'ok') {
 # Now create user.
         my $type = 'auto';
@@ -575,6 +574,8 @@ sub create_newuser {
         } else {
             $$logmsg .= &mt('An error occurred adding new user [_1] - [_2].',$uname,$outcome).$linefeed;
         }
+    } else {
+        $$logmsg .= &mt('An error occurred adding the new user [_1] because the authcheck failed for authtype [_2] and parameter [_3].',$uname,$auth,$authparam).' '.&mt('The authcheck response was [_1].',$authchk).$linefeed;
     }
     return $outcome;
 }
