@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.263 2006/12/13 22:48:07 albertel Exp $
+# $Id: lonhomework.pm,v 1.267 2007/04/07 00:12:42 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -96,7 +96,6 @@ sub get_target {
 	    return ('grade','webgrade');
 	}
 	if ( defined($env{'form.submitted'}) &&
-	     ( !defined($env{'form.resetdata'})) &&
 	     ( !defined($env{'form.newrandomization'}))) {
 	    return ('grade', 'web');
 	} else {
@@ -113,7 +112,10 @@ sub get_target {
 		return ('web');
 	    }
 	} else {
-	    if ( $env{'form.problemmode'} eq &mt('View') ||
+	    if ($env{'form.problemstate'} eq 'WEB_GRADE') {
+		#$env{'form.webgrade'} = 'yes';
+		return ('grade','webgrade','answer');
+	    } elsif ( $env{'form.problemmode'} eq &mt('View') ||
 		 $env{'form.problemmode'} eq &mt('Discard Edits and View')) {
 		if ( defined($env{'form.submitted'}) &&
 		     (!defined($env{'form.resetdata'})) &&
@@ -663,9 +665,19 @@ sub handle_save_or_undo {
 	if ((!$error) && (!copy($filebak,$file))) { $error=1; }
 	if ((!$error) && (!move($filetmp,$filebak))) { $error=1; }
 	if (!$error) {
-	    &Apache::lonxml::info("<p><b>".&mt("Undid changes, Switched")." $filebak ".&mt("and")." $file</b></p>");
+	    &Apache::lonxml::info("<p><b>".
+				  &mt("Undid changes, Switched [_1] and [_2]",
+				      '<span class="LC_filename">'.$filebak.
+				      '</span>',
+				      '<span class="LC_filename">'.$file.
+				      '</span>')."</b></p>");
 	} else {
-	    &Apache::lonxml::info("<p><font color=\"red\" size=\"+1\"><b>".&mt("Unable to undo, unable to switch")." $filebak ".&mt("and")." $file</b></font></p>");
+	    &Apache::lonxml::info("<p><span class=\"LC_error\">".
+				  &mt("Unable to undo, unable to switch [_1] and [_2]",
+				      '<span class="LC_filename">'.
+				      $filebak.'</span>',
+				      '<span class="LC_filename">'.
+				      $file.'</span>')."</span></p>");
 	    $error=1;
 	}
     } else {
@@ -673,20 +685,29 @@ sub handle_save_or_undo {
 	my $fs=Apache::File->new(">$filebak");
 	if (defined($fs)) {
 	    print $fs $$problem;
-	    &Apache::lonxml::info("<b>".&mt("Making Backup to").
-				  " $filebak</b>");
+	    &Apache::lonxml::info("<b>".&mt("Making Backup to [_1]",
+					    '<span class="LC_filename">'.
+					    $filebak.'</span>').
+				  "</b>");
 	} else {
-	    &Apache::lonxml::info("<font color=\"red\" size=\"+1\"><b>".&mt("Unable to make backup")." $filebak</b></font>");
+	    &Apache::lonxml::info("<span class=\"LC_error\">".
+				  &mt("Unable to make backup [_1]",
+				      '<span class="LC_filename">'.
+				      $filebak.'</span>')."</span>");
 	    $error=2;
 	}
 	my $fh=Apache::File->new(">$file");
 	if (defined($fh)) {
 	    print $fh $$result;
-	    &Apache::lonxml::info("<b>".&mt("Saving Modifications to").
-				  " $file</b>");
+	    &Apache::lonxml::info("<b>".&mt("Saving Modifications to [_1]",
+					   '<span class="LC_filename">'.
+					    $file.'</span>' )."</b>");
 	} else {
-	    &Apache::lonxml::info("<font color=\"red\" size=\"+1\"><b>".
-				  &mt("Unable to write to")." $file</b></font>");
+	    &Apache::lonxml::info('<span class="LC_error">'.
+				  &mt("Unable to write to [_1]",
+				      '<span class="LC_filename">'.
+				      $file.'</span>').
+				  '</span>');
 	    $error|=4;
 	}
     }
@@ -760,7 +781,7 @@ sub analyze {
 			      $answer_part);
 			my $concatanswer= join("\0",@{ $answer_part });
 			if (($concatanswer eq '') || ($concatanswer=~/^\@/)) {
-			    $answer_part = ['<font color="red">'.&mt('Error').'</font>'];
+			    $answer_part = ['<span class="LC_error">'.&mt('Error').'</span>'];
 			}
 			$seedexample{join("\0",$part,$i,@{$answer_part})}=
 			    $thisseed;
@@ -841,8 +862,9 @@ sub editxmlmode {
 	if ($cols < 70) { $cols = 70; }
 	if ($rows < 20) { $rows = 20; }
 	my $start_page = 
-	    &Apache::loncommon::start_page("EditXML $file",
-					   &Apache::edit::js_change_detection());
+	    &Apache::loncommon::start_page(&mt("EditXML [_1]",$file),
+					   &Apache::edit::js_change_detection(),
+					   {'no_auto_mt_title' => 1,});
 
 	$result.=$start_page.
 	    &renderpage($request,$file,['no_output_web'],1).
@@ -999,7 +1021,7 @@ sub newproblem {
 	my $dest = &Apache::lonnet::filelocation("",$request->uri);
 	my $errormsg;
 	if ($env{'form.newfile'}) {
-	    $errormsg='<p><font color="red">'.&mt('You did not select a template.').'</font></p>'."\n";
+	    $errormsg='<p><span class="LC_error">'.&mt('You did not select a template.').'</span></p>'."\n";
 	}
 	my $instructions;
 	my $start_page = 
