@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.377 2007/05/23 22:36:21 albertel Exp $
+# $Id: structuretags.pm,v 1.379 2007/06/05 22:37:56 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -103,12 +103,8 @@ function setSubmittedPart (part) {
 	
 	$extra_head .= &Apache::lonhtmlcommon::spellheader();
 
-	my $css_href = &Apache::lonnet::EXT('resource.0.cssfile');
-	if ($css_href =~ /\S/) {
-	    &Apache::lonxml::extlink($css_href);
-	    $extra_head .= 
-		'<link rel="stylesheet" type="text/css" href="'.$css_href.'" />';
-	}
+	$extra_head .= &Apache::londefdef::generate_css_links();
+
 	if ($target eq 'edit') {
 	    $extra_head.=&Apache::edit::js_change_detection().
 		"<script type=\"text/javascript\">\n".
@@ -1226,7 +1222,7 @@ sub end_while {
 	while ($return) {
 	    if (time-$starttime >
 		$Apache::lonnet::perlvar{'lonScriptTimeout'}) {
-		#$return = 0; $error=1; next;
+		$return = 0; $error=1; next;
 	    }
 	    $result.=&Apache::scripttag::xmlparse($bodytext);
 	    $return = &Apache::run::run($code,$safeeval);
