@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.156 2007/01/16 21:20:57 albertel Exp $
+# $Id: lonindexer.pm,v 1.158 2007/03/08 01:58:45 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -856,8 +856,8 @@ sub display_line {
 		   '\')"><img alt="" src="'.$iconpath.'server.gif"');
 	$r->print (' border="0" /></a>'."\n");
 	$r->print (&mt("Domain")." - $listname ");
-	if ($Apache::lonnet::domaindescription{$listname}) {
-	    $r->print("(".$Apache::lonnet::domaindescription{$listname}.
+	if (&Apache::lonnet::domain($listname,'description')) {
+	    $r->print("(".&Apache::lonnet::domain($listname,'description').
 		      ")");
 	}
 	$r->print ("</form>$tabtag</tr>\n");
@@ -1203,7 +1203,7 @@ sub showpreview {
        $output='<img alt="'.&mt('Preview').'" src="'.$filelink.'" />';
     } elsif ($filelink=~m{^/res/($match_domain)/($match_username)/}) {
        $output='<img  alt="'.&mt('Preview').'" src="http://'.
-                 $Apache::lonnet::hostname{&Apache::lonnet::homeserver($2,$1)}.
+                 &Apache::lonnet::hostname(&Apache::lonnet::homeserver($2,$1)).
                  '/cgi-bin/thumbnail.gif?url='.$filelink.'" />';
     }
     return $output;
