@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.21 2006/12/06 22:22:37 albertel Exp $
+# $Id: lontrackstudent.pm,v 1.23 2007/02/13 01:44:02 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -110,12 +110,21 @@ sub get_data {
     &Apache::lonhtmlcommon::Update_PrgWin
         ($r,$prog_state,&mt('Parsing results'));
     #
-    &output_results($r,$results_file,$navmap,$mode);
+    my $last = &output_results($r,$results_file,$navmap,$mode);
     my ($sname,$sdom) = ($mode=~/^student:(.*):(.*)$/);
-    $r->print(&Apache::loncommon::track_student_link(
-				  'View more activity by this student',
-				  $sname,$sdom,undef,
-				  ($env{'form.start'}+$num_records)));
+    
+    my ($text,$inc);
+    if ( $last > 0 && (($last+1) >= $env{'form.start'}+$num_records) ) {
+	$text = 'View more activity by this student';
+	$inc  = $num_records;
+	$r->print(&Apache::loncommon::track_student_link($text,$sname,$sdom,undef,
+							 ($env{'form.start'}+$inc)
+							 ));
+	$r->print('<br />');
+    }
+    $text = 'Resubmit last request to check for newer data';
+    $r->print(&Apache::loncommon::track_student_link($text,$sname,$sdom,undef,
+						     $env{'form.start'}));
 
     &Apache::lonhtmlcommon::Update_PrgWin($r,$prog_state,&mt('Finished!'));
     return;
@@ -239,7 +248,7 @@ sub output_results {
     if (! -s $results_file) {
         # results file is empty, just let them know there is no data
         $r->print('<h2>'.&mt('So far, no data has been returned for your request').'</h2>');
-        return;
+        return -1;
     }
     if (! open(ACTIVITYDATA,$results_file)) {
         $r->print('<h2>'.&mt('Unable to read results file.').'</h2>'.
@@ -248,7 +257,7 @@ sub output_results {
                       'You should contact your system administrator '.
                       'to resolve this issue.').
                   '</p>');
-        return;
+        return -2;
     }
     ##
     ##
@@ -307,10 +316,11 @@ sub output_results {
                 $title = $nav_res->compTitle();
                 $src   = $nav_res->src();
             } else {
-                if ($src =~ m|^/res|) {
-                    $title = $src;
-                } elsif ($values =~ /^\s*$/ && 
-                         (! defined($src) || $src =~ /^\s*$/)) {
+		$src = $symb;
+		if ($src !~ m{/adm}) {
+		    $title = &Apache::lonnet::gettitle($src);
+		} elsif ($values =~ /^\s*$/ && 
+		    (! defined($src) || $src =~ /^\s*$/)) {
                     next;
                 } elsif ($values =~ /^\s*$/) {
                     $values = $src;
@@ -370,7 +380,7 @@ sub output_results {
     }
     $r->print('</table>'.$/);### if (! $count % 50);
     close(ACTIVITYDATA);
-    return;
+    return $count;
 }
 
 ###################################################################
@@ -388,8 +398,11 @@ sub display_values {
 	}
 	$result.='</table>';
     } elsif ($action eq 'POST') {
-	my %values=
-	    map {split('=',&unescape($_),-1)} split(/\&/,$values);
+	my %values;
+        foreach my $pair (split(/\&/,$values)) {
+            my ($key,$value) = split('=',&unescape($pair),-1);
+            $values{$key} = $value;
+        }
 	foreach my $key (sort(keys(%values))) {
 	    if ($key eq 'counter') { next; }
 	    $result.='<tr><td align="right">'.$key.'</td>'.
