@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.67 2006/12/20 23:02:33 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.71 2007/05/02 01:33:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -144,7 +144,6 @@ sub display_main_box {
     my ($r,$command,$refpage,$checkallowed) = @_;
     my $domain=&Apache::loncommon::determinedomain();
     my $function = &Apache::loncommon::get_users_function();
-    my $tabbg=&Apache::loncommon::designparm($function.'.tabbg',$domain);
     my $lctype = lc(&Apache::loncommon::course_type());
     $r->print('<table width="100%" border="0" cellpadding="5" cellspacing="0"><tr><td width="100%">');
 
@@ -172,7 +171,7 @@ sub display_main_box {
 
     if (($command eq 'chgthreshold') 
 	&& $checkallowed->{'abovethreshold'}) {
-        &display_threshold_config($r,$refpage,$tabbg,\%threshold_titles,
+        &display_threshold_config($r,$refpage,\%threshold_titles,
                                                                    $cdom,$crs);
     } elsif (($command eq 'chginterval') 
 	     && $checkallowed->{'versionchanges'}) {
@@ -183,7 +182,7 @@ sub display_main_box {
     } elsif ($command eq 'courseinit') {
         &courseinit_config($r,$refpage,\%initpage);
     } else {
-        &display_actions_box($r,$tabbg,$command,$refpage,\%threshold_titles,
+        &display_actions_box($r,$command,$refpage,\%threshold_titles,
                         \%interval_titles,\%initpage,$cdom,$crs,$checkallowed);
     }
     my $end_page = &Apache::loncommon::end_page();
@@ -241,11 +240,8 @@ END
 #-------------------------------
                                                                                 
 sub display_actions_box {
-    my ($r,$tabbg,$command,$refpage,$threshold_titles,$interval_titles,
-                                      $initpage,$cdom,$crs,$checkallowed) = @_;
-    my $rowColor1 = "#ffffff";
-    my $rowColor2 = "#eeeeee";
-
+    my ($r,$command,$refpage,$threshold_titles,$interval_titles,$initpage,
+        $cdom,$crs,$checkallowed) = @_;
     my $udom = $env{'user.domain'};
     my $uname = $env{'user.name'};
     my $cid = $env{'request.course.id'};
@@ -315,7 +311,7 @@ sub display_actions_box {
     $r->print(&mt('Page set to be displayed after you have selected a role in this '.$lctype).
               '. <nobr>'.&mt('Currently: <i>[_1]</i>',$currinit).'.&nbsp;&nbsp;'.
               &mt('<b>Change</b> for just <a href="/adm/whatsnew?command=courseinit&refpage=[_1]">this '.$lctype.'</a>',$refpage).' '.
-              &mt('or for all <a href="/adm/preferences?action=changecourseinit&refpage=[_1]">your courses</a>',$refpage).'</nobr><br /><hr />');
+              &mt('or for all <a href="/adm/preferences?action=changecourseinit&refpage=[_1]">your courses</a>.',$refpage).'</nobr><br /><hr />');
 
     if ($command eq 'reset') {
         $result = &process_reset($cdom,$crs);
@@ -330,9 +326,9 @@ sub display_actions_box {
     my $store_result=&store_display_settings($uname,$udom,$cid,$checkallowed);
 
     unless ($store_result eq 'ok') { 
-        &Apache::lonnet::logthis('Error storing whatsnew settings: '.
+        &Apache::lonnet::logthis('Error saving whatsnew settings: '.
             $store_result.' for '.'user '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
-        $result .= &mt('Unable to store visibility settings due to [_1]',
+        $result .= &mt('Unable to save visibility settings due to [_1]',
                        $store_result); 
     }
 
@@ -396,7 +392,7 @@ sub display_actions_box {
     }
 
     if ($needitems) {
-        &getitems(\%unread,\%ungraded,\%bombed,\%triggered,\%changed,\@newdiscussions,\@tograde,\@bombs,\@warnings,$rowColor1,$rowColor2,\%threshold,$cdom,$crs,\%res_title,\%show,$starttime,$countunread);
+        &getitems(\%unread,\%ungraded,\%bombed,\%triggered,\%changed,\@newdiscussions,\@tograde,\@bombs,\@warnings,\%threshold,$cdom,$crs,\%res_title,\%show,$starttime,$countunread);
     }
     if ($show{'coursenormalmail'}) {
         $msgcount = &getnormalmail(\@newmsgs);
@@ -432,7 +428,7 @@ sub display_actions_box {
             if ($displayed == $halfway) {
                 $r->print('</td><td width="6%">&nbsp;</td><td align="left" valign="top" width="47%">');
             }
-            &display_launcher($r,$actionitem,$refpage,$checkallowed,$tabbg,$rowColor1,$rowColor2,\%show,\%headings,\%res_title,\@tograde,\%ungraded,\@bombs,\%bombed,\%changed,\@warnings,\%triggered,\@newdiscussions,\%unread,$msgcount,\@newmsgs,$critmsgcount,\@critmsgs,$interval,$countunread);
+            &display_launcher($r,$actionitem,$refpage,$checkallowed,\%show,\%headings,\%res_title,\@tograde,\%ungraded,\@bombs,\%bombed,\%changed,\@warnings,\%triggered,\@newdiscussions,\%unread,$msgcount,\@newmsgs,$critmsgcount,\@critmsgs,$interval,$countunread);
             $displayed ++; 
         }
     }
@@ -454,7 +450,7 @@ sub display_actions_box {
 #-------------------------------
                                                                                 
 sub display_threshold_config {
-    my ($r,$refpage,$tabbg,$threshold_titles,$cdom,$crs) = @_;
+    my ($r,$refpage,$threshold_titles,$cdom,$crs) = @_;
     my $uname = $env{'user.name'};
     my $udom = $env{'user.dom'};
     my $cid = $env{'request.course.id'};
@@ -471,48 +467,31 @@ sub display_threshold_config {
                          );
     &get_curr_thresholds(\%threshold,$uname,$udom,$cid,$cdom,$crs);
 
-    $r->print('<br /><form name="thresholdform" method="post" action="/adm/whatsnew">
-        <table border="0" cellpadding="2" cellspacing="4">
-         <tr>
-          <td align="left" valign="top" width="45%">
-           <table border="0" cellpadding="0" cellspacing="0" bgcolor="#000000">
-            <tr>
-             <td>
-               <table border="0" cellpadding="1" cellspacing="1" bgcolor="#000000">
-                <tr>
-                <td bgcolor="#ffffff">
-                 <table cellspacing="0" cellpadding="4" border="0">
-     <tr bgcolor="'.$tabbg.'">
-      <th>Threshold Name</th>
-      <th>Current value</th>
-      <th>Change?</th>
-     </tr>');
-    my $rowNum =0;
+    $r->print('<br /><form name="thresholdform" method="post" action="/adm/whatsnew">'.
+              &Apache::loncommon::start_data_table().
+              &Apache::loncommon::start_data_table_header_row().
+             '<th>'.&mt('Threshold Name').'</th>'."\n".
+             '<th>'.&mt('Current value').'</th>'."\n".
+             '<th>'.&mt('Change?').'</th>'."\n".
+              &Apache::loncommon::end_data_table_header_row());
     foreach my $type (@thresholditems) {
         my $parameter = $env{'request.course.id'}.':threshold_'.$type;
 # onchange is javascript to automatically check the 'Set' button.
         my $onchange = 'onFocus="javascript:window.document.forms'.
               "['thresholdform'].elements['".$parameter."_setparmval']".
               '.checked=true;"';
-        if ($rowNum %2 == 1) {
-            $rowColor = $rowColor1;
-        } else {
-            $rowColor = $rowColor2;
-        }
-        $r->print('
-     <tr bgcolor="'.$rowColor.'">
-      <td>'.$threshold_titles{$type}.'</td>
-      <td>'.&Apache::lonhtmlcommon::textbox($parameter.'_value',
+        $r->print(&Apache::loncommon::start_data_table_row()."\n".
+                 '<td>'.$threshold_titles{$type}.'</td>'."\n".
+                 '<td>'.&Apache::lonhtmlcommon::textbox($parameter.'_value',
                                             $threshold{$type},
-                                            10,$onchange).'</td>
-      <td>'
-           .&Apache::lonhtmlcommon::checkbox($parameter.'_setparmval').
-      '</td>
-     </tr>');
-        $rowNum ++;
+                                            10,$onchange).'</td>'."\n".
+                 '<td>'.
+                 &Apache::lonhtmlcommon::checkbox($parameter.'_setparmval').
+                 '</td>'."\n".
+                 &Apache::loncommon::end_data_table_row());
     }
-    $r->print('</table></td></tr></table></td></tr></table>
-           <br /><input type="submit" name="threshold" value="Make changes" />
+    $r->print(&Apache::loncommon::end_data_table()."\n".
+          '<br /><input type="submit" name="threshold" value="Make changes" />
                  <input type="hidden" name="command" value="update" />
                  <input type="hidden" name="refpage" value="'.$refpage.'" />
                </form>');
@@ -542,7 +521,7 @@ sub display_interval_config {
 <select name="interval">
 ');
     foreach my $key (reverse sort ({$a cmp $b} (keys(%{$interval_titles})))) {
-        $r->print('<option value="'.$key.'">Version changes '.$$interval_titles{$key}.
+        $r->print('<option value="'.$key.'">'.&mt('Version changes').' '.$$interval_titles{$key}.
                   '</option>'."\n");
     }
     $r->print('</select>&nbsp;&nbsp;
@@ -577,7 +556,7 @@ function toggle_countunread(choice) {
     document.discussionswitch.submit();
 }
 </script>');
-    $r->print('<br />'.&mt('Choose whether or not to display a count of the number of new posts for each resource or bulletin board which has unread posts.').'<br />'.&mt('This can increase the time taken to gather data for the [_1] page by a few seconds.',"<i>What's New?</i>").'&nbsp;&nbsp;'.&mt('Currently set to [_1].','<b>'.$current.'</b>'));
+    $r->print('<br />'.&mt('Choose whether or not to display a count of the number of new posts for each resource or bulletin board which has unread posts.').'<br />'.&mt("This can increase the time taken to gather data for the '<i>What's New?</i>' page by a few seconds.").'&nbsp;&nbsp;'.&mt("Currently set to <b>$current</b>."));
     $r->print('<br /><br />
 <form method="post" name="discussionswitch" action="/adm/whatsnew">
 <input type="hidden" name="command" value="newdiscconf" />
@@ -674,36 +653,30 @@ sub curr_courseinit {
 }
 
 sub display_launcher {
-    my ($r,$action,$refpage,$checkallowed,$tabbg,$rowColor1,$rowColor2,$show,
-        $headings,$res_title,$tograde,$ungraded,$bombs,$bombed,$changed,
-        $warnings,$triggered,$newdiscussions,$unread,$msgcount,$newmsgs,
-                          $critmsgcount,$critmsgs,$interval,$countunread) = @_;
+    my ($r,$action,$refpage,$checkallowed,$show,$headings,$res_title,
+        $tograde,$ungraded,$bombs,$bombed,$changed,$warnings,$triggered,
+        $newdiscussions,$unread,$msgcount,$newmsgs,$critmsgcount,$critmsgs,
+        $interval,$countunread) = @_;
 
     if ($$checkallowed{$action}) {
-        &start_box($r,$tabbg,$show,$headings,$action,$refpage,$action);
+        &start_box($r,$show,$headings,$action,$refpage,$action);
         if ($$show{$action}) {
             if ($action eq 'handgrading') {    # UNGRADED ITEMS
-                &display_handgrade($r,$tograde,$rowColor1,$rowColor2,
-                                                                    $ungraded);
+                &display_handgrade($r,$tograde,$ungraded);
             } elsif ($action eq 'haserrors') { # BOMBS
-                &display_haserrors($r,$bombs,$rowColor1,$rowColor2,$bombed,
-                                                                   $res_title);
+                &display_haserrors($r,$bombs,$bombed,$res_title);
             } elsif ($action eq 'versionchanges') { # VERSION CHANGES
-                &display_versionchanges($r,$changed,$res_title,$rowColor1,
-                                                         $rowColor2,$interval);
-
+                &display_versionchanges($r,$changed,$res_title,$interval);
             } elsif ($action eq 'abovethreshold') { # DEGDIFF/AV. TRIES TRIGGERS
                 &display_abovethreshold($r,$refpage,$warnings,$triggered,
 					$res_title);
             } elsif ($action eq 'coursediscussion') { # UNREAD COURSE DISCUSSION
                 &display_coursediscussion($r,$newdiscussions,$unread,
-                                $countunread,$res_title,$rowColor1,$rowColor2);
+                                $countunread,$res_title);
             } elsif ($action eq 'coursenormalmail') { # NORMAL MESSAGES
-                &display_coursenormalmail($r,$msgcount,$newmsgs,$rowColor1,
-                                                                   $rowColor2);
+                &display_coursenormalmail($r,$msgcount,$newmsgs);
             } elsif ($action eq 'coursecritmail') { # CRITICAL MESSAGES
-                &display_coursecritmail($r,$critmsgcount,$critmsgs,$rowColor1,
-                                                                   $rowColor2);
+                &display_coursecritmail($r,$critmsgcount,$critmsgs);
             }
         }
         &end_box($r);
@@ -713,8 +686,8 @@ sub display_launcher {
 
 sub getitems {
     my ($unread,$ungraded,$bombed,$triggered,$changed,$newdiscussions,
-        $tograde,$bombs,$warnings,$rowColor1,$rowColor2,$threshold,$cdom,$crs,
-                                 $res_title,$show,$starttime,$countunread) = @_;
+        $tograde,$bombs,$warnings,$threshold,$cdom,$crs,$res_title,$show,
+        $starttime,$countunread) = @_;
     my $navmap = Apache::lonnavmaps::navmap->new();
     # force retrieve Resource to seed the part id cache we'll need it later
     my @allres=$navmap->retrieveResources(undef,
@@ -849,7 +822,6 @@ sub check_thresholds {
     my %stats;
     my %lastreset = ();
     my $warning = 0;
-    my $rowColor;
     foreach my $part (@parts) {
         if ($resource->handgrade($part) eq 'yes') {
             next;
@@ -1139,22 +1111,20 @@ sub checkversions {
 }
 
 sub display_handgrade {
-    my ($r,$tograde,$rowColor1,$rowColor2,$ungraded) = @_;
-    my $rowColor;
+    my ($r,$tograde,$ungraded) = @_;
     my %lt = &Apache::lonlocal::texthash(
                         'prna' => 'Problem Name',
                         'nmun' => 'Number ungraded',
                         'nopr' => 'No problems require handgrading',
     );
     if (@{$tograde} > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.$lt{'prna'}.'</small></b></td><td align="right"><b><small>'.$lt{'nmun'}.'</small></b></td></tr>');
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  $lt{'prna'}.'</td><td class="LC_right_item">'.
+                  $lt{'nmun'}.'</td></tr>');
         my $rowNum = 0;
         foreach my $res (@{$tograde}) {
-            if ($rowNum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
+            $rowNum ++;
+            my $css_class = $rowNum%2?' class="LC_odd_row"':'';
             my ($map,$id,$url)=&Apache::lonnet::decode_symb($res);
             my $linkurl=&Apache::lonnet::clutter($url);
             $linkurl .= '?symb='.&escape($res);
@@ -1162,37 +1132,35 @@ sub display_handgrade {
                 $linkurl = 
                     $$ungraded{$res}{'enclink'}.'?symb='.$$ungraded{$res}{'encsymb'};
             } 
-            $r->print('<tr bgcolor="'.$rowColor.'"><td><a href="'.$linkurl.'"><small>'.$$ungraded{$res}{title}.'</small></a></td><td align="right"><small>'.$$ungraded{$res}{count}.'</small></td></tr>');
-            $rowNum ++;
+            $r->print('<tr'.$css_class.'><td><a href="'.$linkurl.'">'.$$ungraded{$res}{title}.'</a></td><td class="LC_right_item">'.$$ungraded{$res}{count}.'</td></tr>');
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff"><br><center><i><b><small>&nbsp;&nbsp;'.$lt{'nopr'}.'&nbsp;&nbsp;</small><br><br></b></i></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.$lt{'nopr'}.'</td></tr>');
     }
 }
 
 sub display_haserrors {
-    my ($r,$bombs,$rowColor1,$rowColor2,$bombed,$res_title) = @_;
+    my ($r,$bombs,$bombed,$res_title) = @_;
     my $bombnum = 0;
-    my $rowColor;
     my %lt = &Apache::lonlocal::texthash(
                                    reso => 'Resource',
                                    nmer => 'Number of errors',
                                    noer => 'No problems with errors',
     );
     if (@{$bombs} > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.$lt{'reso'}.'</small></b></td><td align="right"><b><small>'.$lt{'nmer'}.'</small></b></td></tr>');
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  $lt{'reso'}.'</td><td class="LC_right_item">'.
+                  $lt{'nmer'}.'</td></tr>');
         @{$bombs} = sort { &cmp_title($a,$b,$res_title) } @{$bombs};
         foreach my $bomb (@{$bombs}) {
-            if ($bombnum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
-            $r->print('<tr bgcolor="'.$rowColor.'"><td><small>'.$$bombed{$bomb}{errorlink}.'</small></td><td align="right"><small>'.$$bombed{$bomb}{errorcount}.'</small></td></tr>');
             $bombnum ++;
+            my $css_class = $bombnum%2?' class="LC_odd_row"':'';
+            $r->print('<tr'.$css_class.'><td>'.$$bombed{$bomb}{errorlink}.
+                      '</td><td class="LC_right_item">'.
+                      $$bombed{$bomb}{errorcount}.'</td></tr>');
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff"><br /><center><b><i><small>'.$lt{'noer'}.'</small></i></b></center><br /></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.$lt{'noer'}.'</td></tr>');
     }
     return;
 }
@@ -1217,10 +1185,11 @@ sub display_abovethreshold {
                 ' <input type="hidden" name="refpage" value="'.$refpage.'" />'.
                 "\n");
         $r->print('<tr class="LC_info_row">'.
-		  '<td class="LC_first_item">'.$lt{'reso'}.'</td>'.
+		  '<td class="LC_left_item">'.$lt{'reso'}.'</td>'.
 		  '<td>'.$lt{'part'}.'</td><td>'.$lt{'nust'}.'</td>'.
 		  '<td>'.$lt{'avat'}.'</td><td>'.$lt{'dedi'}.'</td>'.
-		  '<td>'.$lt{'lare'}.'</td><td>'.$lt{'reco'}.'</td></tr>');
+		  '<td>'.$lt{'lare'}.'</td><td  class="LC_right_item">'.
+                  $lt{'reco'}.'</td></tr>');
 	my $row;
         foreach my $res (@{$warnings}) {
 	    $row++;
@@ -1235,8 +1204,8 @@ sub display_abovethreshold {
                 $linkurl = 
                   $$triggered{$res}{'enclink'}.'?symb='.$$triggered{$res}{'encsymb'};
             }
-            my $css_class = $row%2?'LC_odd_row':'';
-            $r->print('<tr class="'.$css_class.'">'.
+            my $css_class = $row%2?' class="LC_odd_row"':'';
+            $r->print('<tr'.$css_class.'>'.
 		      '<td class="LC_first_item" '.$rowspan.'><a href="'.$linkurl.'">'.
 		      $$triggered{$res}{title}.'</a></td>');
                       if (ref($$triggered{$res}{text}) eq 'ARRAY') {
@@ -1252,14 +1221,14 @@ sub display_abovethreshold {
                 }
             }
         }
-        $r->print('<tr class="LC_info_row"><td colspan="7"><br /><input type="submit" name="counters" value="'.$lt{'rese'}.'" /></td></tr></form>');
+        $r->print('<tr class="LC_info_row"><td colspan="7" class="LC_right_item"><br /><input type="submit" name="counters" value="'.$lt{'rese'}.'" /></td></tr></form>');
     } else {
         $r->print('<tr class="LC_empty_row"><td>'.$lt{'nopr'}.'</td></tr>');
     }
 }
 
 sub display_versionchanges {
-    my ($r,$changed,$res_title,$rowColor1,$rowColor2,$interval) = @_;
+    my ($r,$changed,$res_title,$interval) = @_;
     my %lt = &Apache::lonlocal::texthash(
         'reso' => 'Resource',
         'revd' => 'Last revised',
@@ -1267,35 +1236,35 @@ sub display_versionchanges {
         'veru' => 'Version used',
         'noup' => 'No updated versions', 
     );
-    my $rowColor;
     if (keys(%{$changed}) > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.$lt{'reso'}.'</small></b></td><td><b><small>'.$lt{'revd'}.'</small></b></td><td><b><small>'.$lt{'newv'}.'</small></b></td><td><b><small>'.$lt{'veru'}.'</small></b></td></tr>');
-        
-        
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  $lt{'reso'}.'</td><td>'.$lt{'revd'}.'</td><td>'.
+                  $lt{'newv'}.'</td><td class="LC_right_item">'.
+                  $lt{'veru'}.'</td></tr>');
         my @changes = sort { &cmp_title($a,$b,$res_title) } keys(%{$changed});
         my $changenum = 0;
         foreach my $item (@changes) {
-            if ($changenum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
+            $changenum ++;
+            my $css_class = $changenum%2?' class="LC_odd_row"':'';
             my ($map,$id,$url)=&Apache::lonnet::decode_symb($item);
             my $linkurl=&Apache::lonnet::clutter($url);
             $linkurl .= '?symb='.&escape($item);
 
-            $r->print('<tr bgcolor="'.$rowColor.'"><td><small><a href="'.$linkurl.'">'.$$res_title{$item}.'</a></small></td><td><small>'.$$changed{$item}{'revdate'}.'</small></td><td><small>'.$$changed{$item}{'current'}.'</small></td><td><small>'.$$changed{$item}{'version'}.'</small></td></tr>');
-            $changenum ++;
+            $r->print('<tr'.$css_class.'><td><a href="'.$linkurl.'">'.
+                      $$res_title{$item}.'</a></td><td>'.
+                      $$changed{$item}{'revdate'}.'</td><td>'.
+                      $$changed{$item}{'current'}.'</td><td>'.
+                      $$changed{$item}{'version'}.'</td></tr>');
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff"><br /><center><b><i><small>'.$lt{'noup'}.' '.$interval.'</small></i></b></center><br /></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.$lt{'noup'}.
+                  ' '.$interval.'</td></tr>');
     }
     return;
 }
  
 sub display_coursediscussion {
-    my ($r,$newdiscussions,$unread,$countunread,$res_title,$rowColor1,
-                                                              $rowColor2) = @_;
+    my ($r,$newdiscussions,$unread,$countunread,$res_title) = @_;
     my $lctype = lc(&Apache::loncommon::course_type());
     my %lt = &Apache::lonlocal::texthash(
                 'loca' => 'Location',
@@ -1304,24 +1273,22 @@ sub display_coursediscussion {
                 'noun' => 'No unread posts in '.$lctype.' discussions',
                 'tmlp' => 'Time of last post', 
     );
-    my $rowColor;
     if (@{$newdiscussions} > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.$lt{'loca'}.
-                  '</small></b></td><td><b><small>'.$lt{'type'}.
-                  '</small></b>');
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  $lt{'loca'}.'</td><td>'.
+                  $lt{'type'}.'</td>');
         if ($countunread eq 'on') {
-            $r->print('<td><b><small>'.$lt{'tmlp'}.'</small></b></td>'.
-                      '<td align="right"><b><small>'.$lt{'numn'}.
-                      '</small></b></td>');
+            $r->print('<td>'.$lt{'tmlp'}.'</td>'.
+                      '<td class="LC_right_item">'.$lt{'numn'}.'</td>');
         } else {
-            $r->print('<td align="right"><b><small>'.$lt{'tmlp'}.
-                         '</small></b></td>');
+            $r->print('<td class="LC_right_item">'.$lt{'tmlp'}.'</td>');
         }
         $r->print("</tr>\n");
         @{$newdiscussions} = sort { &cmp_title($a,$b,$res_title) }
                                                             @{$newdiscussions};
         my $rowNum = 0;
         foreach my $ressymb (@{$newdiscussions}) {
+            $rowNum ++;
             my $forum_title = $$unread{$ressymb}{'title'};
             my $type = 'Resource';
             my $feedurl=&Apache::lonfeedback::get_feedurl($ressymb);
@@ -1332,73 +1299,70 @@ sub display_coursediscussion {
             if ($$unread{$ressymb}{'enclink'}) {
                 $disclink = $$unread{$ressymb}{'enclink'}.'?symb='.$$unread{$ressymb}{'encsymb'};
             }
-            if ($rowNum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
+            my $css_class = $rowNum%2?' class="LC_odd_row"':'';
             my $lastpost = &Apache::lonnavmaps::timeToHumanString(
                                                $$unread{$ressymb}{'lastpost'});
-            $r->print('<tr bgcolor="'.$rowColor.'"><td><small><a href="'.$disclink.'">'.$forum_title.'</a>&nbsp;</td><td><small>'.$type.'&nbsp;</small></td>');
+            $r->print('<tr'.$css_class.'><td><a href="'.$disclink.'">'.$forum_title.'</a>&nbsp;</td><td>'.&mt($type).'&nbsp;</td>');
             if ($countunread eq 'on') {
                 my $unreadnum = $$unread{$ressymb}{'unreadcount'};
-                $r->print('<td><small>'.$lastpost.'<small></td><td align="right">'.
-                          '<small>',$unreadnum.'&nbsp;</small></td>');
+                $r->print('<td>'.$lastpost.'</td><td class="LC_right_item">'.
+                          $unreadnum.'&nbsp;</td>');
             } else {
-                $r->print('<td align="right"><small>'.$lastpost.'</small></td>');
+                $r->print('<td class="LC_right_item">'.$lastpost.'</td>');
             }
             $r->print("</tr>\n");
-            $rowNum ++;
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff"><br><center>&nbsp;<i><b><small>'.
-                  $lt{'noun'}.'</small></b></i><br><br></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.$lt{'noun'}.'</td></tr>');
     }
 }
 
 sub display_coursenormalmail {
-    my ($r,$msgcount,$newmsgs,$rowColor1,$rowColor2) = @_;
-    my $rowColor;
+    my ($r,$msgcount,$newmsgs) = @_;
     my $lctype = lc(&Apache::loncommon::course_type());
     if ($msgcount > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.&mt('Number').'</small></b></td><td><b><small>'.&mt('Subject').'</small></b></td><td><b><small>'.&mt('Sender').'</small></b></td><td><b><small>'.&mt('Date/Time').'</small></b></td></tr>');
-        my $rowNum = 0;
-        my $mailcount = 1;
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  &mt('Number').'</td><td>'.&mt('Subject').'</td><td>'.
+                  &mt('Sender').'</td><td class="LC_right_item">'.
+                  &mt('Date/Time').'</td></tr>');
+        my $mailcount = 0;
         foreach my $msg (@{$newmsgs}) {
-            if ($rowNum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
-            $r->print('<tr bgcolor="'.$rowColor.'"><td valign="top"><small>'.$mailcount.'. &nbsp;</small></td><td valign="top"><small><a href="/adm/communicate">'.$msg->{'shortsub'}.'</a>&nbsp; &nbsp;</small></td><td valign="top"><small>&nbsp;'.$msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</small></td><td valign="top"><small>'.$msg->{'sendtime'}.'</small></td></tr>');
-            $rowNum ++;
             $mailcount ++;
+            my $css_class = $mailcount%2?' class="LC_odd_row"':'';
+            $r->print('<tr'.$css_class.'><td>'.$mailcount.
+                      '. &nbsp;</td><td><a href="/adm/communicate">'.
+                      $msg->{'shortsub'}.'</a>&nbsp; &nbsp;</td><td>&nbsp;'.
+                      $msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
+                      $msg->{'sendtime'}.'</td></tr>');
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff" width="100%"><center><br /><b><i><small>'.&mt('No new '.$lctype.' messages').'</small></i></b><br /><br /></center></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.
+                  &mt('No new '.$lctype.' messages').'</td></tr>');
     }
 }
 
 sub display_coursecritmail {
-    my ($r,$critmsgcount,$critmsgs,$rowColor1,$rowColor2) = @_;
-    my $rowColor;
+    my ($r,$critmsgcount,$critmsgs) = @_;
     my $lctype = lc(&Apache::loncommon::course_type());
     if ($critmsgcount > 0) {
-        $r->print('<tr bgcolor="#cccccc"><td><b><small>'.&mt('Number').'</small></b></td><td><b><small>'.&mt('Subject').'</small></b></td><td><b><small>'.&mt('Sender').'</small></b></td><td><b><small>'.&mt('Date/Time').'</small></b></td></tr>');
-        my $rowNum = 0;
-        my $mailcount = 1;
+        $r->print('<tr class="LC_info_row"><td class="LC_left_item">'.
+                  &mt('Number').'</td><td>'.&mt('Subject').'</td><td>'.
+                  &mt('Sender').'</td><td class="LC_right_item">'.
+                  &mt('Date/Time').'</td></tr>');
+        my $mailcount = 0;
         foreach my $msg (@{$critmsgs}) {
-            if ($rowNum %2 == 1) {
-                $rowColor = $rowColor1;
-            } else {
-                $rowColor = $rowColor2;
-            }
-            $r->print('<tr bgcolor="'.$rowColor.'"><td valign="top"><small>'.$mailcount.'. &nbsp;<small></td><td valign="top"><small><a href="/adm/email?folder=critical">'.$msg->{'shortsub'}.'</a>&nbsp; &nbsp;</small></td><td valign="top"><small>&nbsp;'.$msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</small></td><td valign="top"><small>'.$msg->{'sendtime'}.'</small></td></tr>');
-            $rowNum ++;
             $mailcount ++;
+            my $css_class = $mailcount%2?' class="LC_odd_row"':'';
+            $r->print('<tr'.$css_class.'><td>'.$mailcount.
+                      '. &nbsp;</td><td><a href="/adm/email?folder=critical">'.
+                      $msg->{'shortsub'}.'</a>&nbsp; &nbsp;</td><td>&nbsp;'.
+                      $msg->{'from'}.'@'.$msg->{'fromdom'}.'&nbsp;</td><td>'.
+                      $msg->{'sendtime'}.'</td></tr>');
         }
     } else {
-        $r->print('<tr><td bgcolor="#ffffff" width="100%"><center><br /><b><i><small>'.&mt('No unread critical messages in '.$lctype).'</small></i></b><br /><br /></center></td></tr>');
+        $r->print('<tr class="LC_empty_row"><td>'.
+                  &mt('No unread critical messages in '.$lctype).
+                  '</td></tr>');
     }
 }
 
@@ -1460,7 +1424,7 @@ sub store_interval_setting {
 
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
-            &Apache::lonnet::logthis('Error storing whatsnew interval setting'.
+            &Apache::lonnet::logthis('Error saving whatsnew interval setting'.
                 ' '.$outcome.' for '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
             $result = &mt('Unable to set interval to [_1] due to [_2].',
                          '<b>'.$$interval_titles{$env{'form.interval'}}.'</b>',
@@ -1484,7 +1448,7 @@ sub store_discussion_setting {
                                                                                   
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
-            &Apache::lonnet::logthis('Error storing whatsnew countunread setting'.
+            &Apache::lonnet::logthis('Error saving whatsnew countunread setting'.
                 ' '.$outcome.' for '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
             $result = &mt('Unable to set "number unread posts display" to [_1]'.
                           ' due to [_2].',
@@ -1522,7 +1486,7 @@ sub store_courseinit_setting {
                     $result = &mt('Page displayed after role selection in this '.$lctype.' set to <b>[_2]</b>',$lctype,$$initpage{$env{'form.courseinit_page'}});
                 }
             } else {
-                &Apache::lonnet::logthis('Error storing whatsnew courseinit '.
+                &Apache::lonnet::logthis('Error saving whatsnew courseinit '.
                                          'setting: '.$outcome.' for '.$uname.
                                          ':'.$udom.' in '.$lctype.' '.$cid);
                 if ($page_control eq 'global preferences') {
@@ -1541,64 +1505,56 @@ sub store_courseinit_setting {
 }
 
 sub start_box {
-    my ($r,$tabbg,$show,$heading,$caller,$refpage) = @_;
+    my ($r,$show,$heading,$caller,$refpage) = @_;
     my %lt = &Apache::lonlocal::texthash( 
                        chth => 'Change thresholds?',
                        chin => 'Change interval?',
                        chop => 'Change options?',
     );
-    my ($showhide,$class);
+    my $showhide;
     if ($$show{$caller}) {
         $showhide = '<b><a href="javascript:change_display(document.visible.'.
-                               'display_'.$caller.",'hide'".');">Hide</a></b>';
+                               'display_'.$caller.",'hide'".');">'.
+                               &mt('Hide').'</a></b>';
    
     } else {
         $showhide = '<b><a href="javascript:change_display(document.visible.'.
-                               'display_'.$caller.",'show'".');">Show</a></b>';
+                               'display_'.$caller.",'show'".');">'.
+                               &mt('Show').'</a></b>';
     }
     
     $r->print('
-         <table border="0" cellpadding="0" cellspacing="0" bgcolor="#000000" width="100%">
+         <table class="LC_nested_outer">
           <tr>
-           <td>
-            <table border="0" cellpadding="1" cellspacing="1" bgcolor="#000000" width="100%">
-              <tr>
-               <td bgcolor="'.$tabbg.'">
-                <table width="100%" border="0" cellspacing="0" cellpadding="0">
-                 <tr>
-                  <td><b>'.$$heading{$caller}.'</b></td>
-                  <td valign="top" align="right">'.$showhide.'</td>
-                 </tr>
-                </table>
-               </td>
-              </tr>');
+           <th>'.$$heading{$caller}.'</th>
+           <th class="LC_right_item">'.$showhide.'</th>
+          </tr>');
      if (($caller eq 'abovethreshold') && ($$show{$caller})) {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td bgcolor="'.$tabbg.'" align="right"><a href="/adm/whatsnew?command=chgthreshold&refpage='.$refpage.'"><b><small>'.$lt{'chth'}.'</small></b></a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgthreshold&refpage='.$refpage.'">'.$lt{'chth'}.'</a></td>
               </tr>');
          }
-	 $class='class="LC_whatsnew"';
      } elsif (($caller eq 'versionchanges') && ($$show{$caller})) {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td bgcolor="'.$tabbg.'" align="right"><a href="/adm/whatsnew?command=chginterval&refpage='.$refpage.'"><b><small>'.$lt{'chin'}.'</small></b></a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chginterval&refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
               </tr>');
          }
      } elsif ($caller eq 'coursediscussion') {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td bgcolor="'.$tabbg.'" align="right"><a href="/adm/whatsnew?command=chgdisc&refpage='.$refpage.'"><b><small>'.$lt{'chop'}.'</small></b></a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgdisc&refpage='.$refpage.'">'.$lt{'chop'}.'</a></td>
               </tr>');
          }
      }
     $r->print('
               <tr>
-               <td bgcolor="#ffffff">
-                <table cellpadding="2" cellspacing="0" border="0" width="100%" '.$class.'>
+               <td colspan="2">
+                <table class="LC_nested">
 ');
     return;
 }
@@ -1606,9 +1562,6 @@ sub start_box {
 sub end_box {
     my ($r) = shift;
     $r->print('
-      </table>
-     </td>
-    </tr>
    </table>
   </td>
  </tr>
