@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.80 2006/12/20 22:41:08 albertel Exp $
+# $Id: loncfile.pm,v 1.83 2007/04/26 21:17:16 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -239,6 +239,9 @@ Returns:
 
 =over 4
 
+=item  string - Either undef, 'warning' or 'error' depending on the
+                type of problem
+
 =item  string - Either where the resource exists as an html string that can
            be embedded in a dialog or an empty string if the resource
            does not exist.
@@ -251,17 +254,27 @@ sub exists {
     my ($user, $domain, $construct) = @_;
     my $published=$construct;
     $published=~
-	s/^\/home\/$user\/public\_html\//\/home\/httpd\/html\/res\/$domain\/$user\//;
-    my $result='';    
+	s{^/home/$user/public_html/}{/home/httpd/html/res/$domain/$user/};
+    my ($type,$result);
     if ( -d $construct ) {
-	return &mt('Error: destination for operation is an existing directory.');
+	return ('error','<p><span class="LC_error">'.&mt('Error: destination for operation is an existing directory.').'</span></p>');
+	
     }
+
     if ( -e $published) {
-	$result.='<p><font color="red">'.&mt('Warning: target file exists, and has been published!').'</font></p>';
+	if ( -e $construct ) {
+	    $type = 'warning';
+	    $result.='<p><span class="LC_warning">'.&mt('Warning: target file exists, and has been published!').'</span></p>';
+	} else {
+	    $type = 'warning';
+	    $result.='<p><span class="LC_warning">'.&mt('Warning: a published file of this names exists.').'</span></p>';
+	}
     } elsif ( -e $construct) {
-	$result.='<p><font color="red">'.&mt('Warning: target file exists!').'</font></p>';
+	$type = 'warning';
+	$result.='<p><span class="LC_warning">'.&mt('Warning: target file exists!').'</span></p>';
     }
-    return $result;
+
+    return ($type,$result);
 }
 
 =pod
@@ -300,9 +313,9 @@ sub checksuffix {
     my $newsuffix;
     if ($new=~m:(.*/*)([^/]+)\.(\w+)$:) { $newsuffix=$3; }
     if ($old=~m:(.*)/+([^/]+)\.(\w+)$:) { $oldsuffix=$3; }
-    if ($oldsuffix ne $newsuffix) {
+    if (lc($oldsuffix) ne lc($newsuffix)) {
 	$result.=
-            '<p><font color="red">'.&mt('Warning: change of MIME type!').'</font></p>';
+            '<p><span class="LC_warning">'.&mt('Warning: change of MIME type!').'</span></p>';
     }
     return $result;
 }
@@ -323,12 +336,12 @@ sub cleanDest {
 	my ($newpath)=($dest=~m|(.*)/|);
 	$newpath=&relativeDest($fn,$newpath,$uname);
 	if (! -d "$newpath") {
-	    $request->print("<p><font color=\"red\">".&mt('You have requested to create file in directory [_1] which doesn\'t exist. The requested directory path has been removed from the requested file name.','"<tt>'.$newpath.'</tt>"')."</font></p>");
+	    $request->print("<p><span class=\"LC_error\">".&mt('You have requested to create file in directory [_1] which doesn\'t exist. The requested directory path has been removed from the requested file name.','"<tt>'.$newpath.'</tt>"')."</span></p>");
 	    $dest=~s|.*/||;
 	}
     }
     if ($foundbad) {
-	$request->print("<p><font color=\"red\">".&mt('Invalid characters in requested name have been removed.')."</font></p>");
+	$request->print("<p><span class=\"LC_error\">".&mt('Invalid characters in requested name have been removed.')."</span></p>");
     }
     return $dest;
 }
@@ -463,9 +476,9 @@ sub Rename1 {
 	    if (-d $fn) {
 		$newfilename=~/\.(\w+)$/;
 		if (&Apache::loncommon::fileembstyle($1) eq 'ssi') {
-		    $request->print('<br /><font color="red">'.
+		    $request->print('<br /><span classr="LC_warning">'.
 				    &mt('Cannot change MIME type of a directory').
-				    '</font>'.
+				    '</span>'.
 				    '<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
 		    return;
 		}
@@ -475,9 +488,9 @@ sub Rename1 {
 	    while ($newfilename=~m:/\.\./:) {
 		$newfilename=~ s:/[^/]+/\.\./:/:g; #remove dir/..
 	    }
-	    my $return=&exists($user, $domain, $newfilename);
+	    my ($type, $return)=&exists($user, $domain, $newfilename);
 	    $request->print($return);
-	    if ($return =~/^Error:/) {
+	    if ($type eq 'error') {
 		$request->print('<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
 		return;
 	    }
@@ -603,9 +616,9 @@ sub Copy1 {
 	    $newfilename=~ s:/[^/]+/\.\./:/:g; #remove dir/..
 	}
 	$request->print(&checksuffix($fn,$newfilename));
-	my $return=&exists($user, $domain, $newfilename);
+	my ($type,$return)=&exists($user, $domain, $newfilename);
 	$request->print($return);
-	if ($return =~/^Error:/) {
+	if ($type eq 'error') {
 	    $request->print('<br /><a href="'.&url($fn).'">'.&mt('Cancel').'</a>');
 	    return;
 	}
@@ -661,9 +674,10 @@ causes the newdir operation to transition into phase 2.  The hidden field
 sub NewDir1 {
     my ($request, $username, $domain, $fn, $newfilename, $mode) = @_;
 
-    my $result=&exists($username,$domain,$newfilename);
+    my ($type, $result)=&exists($username,$domain,$newfilename);
+    $request->print($result);
     if ($result) {
-	$request->print('<font color="red">'.$result.'</font></form>');
+	$request->print('</form>');
     } else {
 	if ($mode eq 'testbank') {
 	    $request->print('<input type="hidden" name="callingmode" value="testbank">');
@@ -737,29 +751,31 @@ sub NewFile1 {
 
         ##Informs User (name).(number).(extension) not allowed 
 	if($newfilename =~ /\.(\d+)\.(\w+)$/){
-	    $r->print('<font color="red">'.$newfilename.
+	    $r->print('<span class="LC_error">'.$newfilename.
 		      ' - '.&mt('Bad Filename').'<br />('.&mt('name').').('.&mt('number').').('.&mt('extension').') '.
-		      ' '.&mt('Not Allowed').'</font>');
+		      ' '.&mt('Not Allowed').'</span>');
 	    return;
 	}
 	if($newfilename =~ /(\:\:\:|\&\&\&|\_\_\_)/){
-	    $r->print('<font color="red">'.$newfilename.
+	    $r->print('<span class="LC_error">'.$newfilename.
 		      ' - '.&mt('Bad Filename').'<br />('.&mt('Must not include').' '.$1.') '.
-		      ' '.&mt('Not Allowed').'</font>');
+		      ' '.&mt('Not Allowed').'</span>');
 	    return;
 	}
 	if ($newfilename !~ /\Q.$extension\E$/) {
-	    if ($newfilename =~ m|^[^\.]*\.([^\.]+)$|) {
+	    if ($newfilename =~ m|/[^/.]*\.(?:[^/.]+)$|) {
 		#already has an extension strip it and add in expected one
-		$newfilename =~ s|.([^\.]+)$||;
+		$newfilename =~ s|(/[^./])\.(?:[^.]+)$|$1|;
 	    }
 	    $newfilename.=".$extension";
 	}
     }
-    my $result=&exists($user,$domain,$newfilename);
-    if($result) {
-	$request->print('<font color="red">'.$result.'</font></form>');
+    my ($type, $result)=&exists($user,$domain,$newfilename);
+    $request->print($result);
+    if ($type eq 'error') {
+	$request->print('</form>');
     } else {
+	
 	$request->print('<p>'.&mt('Make new file').' '.&display($newfilename).'?</p>');
 	$request->print('</form>');
 	$request->print('<form action="'.&url($newfilename).
@@ -894,7 +910,7 @@ sub Rename2 {
 	my $oRN=$oldfile;
 	my $nRN=$newfile;
 	unless (rename($oldfile,$newfile)) {
-	    $request->print('<font color="red">'.&mt('Error').': '.$!.'</font>');
+	    $request->print('<span class="LC_error">'.&mt('Error').': '.$!.'</span>');
 	    return 0;
 	}
 	## If old name.(extension) exits, move under new name.
@@ -968,12 +984,12 @@ sub Delete2 {
     my ($request, $user, $filename) = @_;
     if (-d $filename) { 
 	unless (&empty_directory($filename,'Delete2')) { 
-	    $request->print('<font color="red"> '.&mt('Error: Directory Non Empty').'</font>'); 
+	    $request->print('<span class="LC_error">'.&mt('Error: Directory Non Empty').'</span>'); 
 	    return 0;
 	} else {   
 	    if(-e $filename) {
 		unless(rmdir($filename)) {
-		    $request->print('<font color="red">'.&mt('Error').': '.$!.'</font>');
+		    $request->print('<span class="LC_error">'.&mt('Error').': '.$!.'</span>');
 		    return 0;
 		}
 	    } else {
@@ -984,7 +1000,7 @@ sub Delete2 {
     } else {
 	if(-e $filename) {
 	    unless(unlink($filename)) {
-		$request->print('<font color="red">'.&mt('Error').': '.$!.'</font>');
+		$request->print('<span class="LC_error">'.&mt('Error').': '.$!.'</span>');
 		return 0;
 	    }
 	} else {
@@ -1028,20 +1044,20 @@ sub Copy2 {
     &Debug($request ,"Will try to copy $oldfile to $newfile");
     if(-e $oldfile) {
         if ($oldfile eq $newfile) {
-            $request->print('<font color="red"> '.&mt('Warning').': '.&mt('Name of new file is the same as name of old file').' - '.&mt('no action taken').'.</font>');
+            $request->print('<span class="LC_error">'.&mt('Warning').': '.&mt('Name of new file is the same as name of old file').' - '.&mt('no action taken').'.</span>');
             return 1;
         }
 	unless (copy($oldfile, $newfile)) {
-	    $request->print('<font color="red"> '.&mt('copy Error').': '.$!.'</font>');
+	    $request->print('<span class="LC_error">'.&mt('copy Error').': '.$!.'</span>');
 	    return 0;
 	} elsif (!chmod(0660, $newfile)) {
-	    $request->print('<font color="red"> '.&mt('chmod error').': '.$!.'</font>');
+	    $request->print('<span class="LC_error">'.&mt('chmod error').': '.$!.'</span>');
 	    return 0;
 	} elsif (-e $oldfile.'.meta' && 
 		 !copy($oldfile.'.meta', $newfile.'.meta') &&
 		 !chmod(0660, $newfile.'.meta')) {
-	    $request->print('<font color="red"> '.&mt('copy metadata error').
-			    ': '.$!.'</font>');
+	    $request->print('<span class="LC_error">'.&mt('copy metadata error').
+			    ': '.$!.'</span>');
 	    return 0;
 	} else {
 	    return 1;
@@ -1079,11 +1095,11 @@ sub NewDir2 {
     my ($request, $user, $newdirectory) = @_;
   
     unless(mkdir($newdirectory, 02770)) {
-	$request->print('<font color="red">'.&mt('Error').': '.$!.'</font>');
+	$request->print('<span class="LC_error">'.&mt('Error').': '.$!.'</span>');
 	return 0;
     }
     unless(chmod(02770, ($newdirectory))) {
-	$request->print('<font color="red"> '.&mt('Error').': '.$!.'</font>');
+	$request->print('<span class="LC_error">'.&mt('Error').': '.$!.'</span>');
 	return 0;
     }
     return 1;
@@ -1310,8 +1326,8 @@ function writeDone() {
     $r->print('<h3>'.&mt('Location').': '.&display($fn).'</h3>');
   
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-	$r->print('<h3><font color="red">'.&mt('Co-Author').': '.$uname.' at '.$udom.
-		  '</font></h3>');
+	$r->print('<h3><span class="LC_error">'.&mt('Co-Author').': '.$uname.' at '.$udom.
+		  '</span></h3>');
     }
 
 
