@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.101 2007/03/09 01:29:51 albertel Exp $
+# $Id: lonpubdir.pm,v 1.102 2007/04/20 01:17:24 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -211,7 +211,8 @@ sub startpage {
 						 {'body_title' =>
 						      $pagetitle,}));
     } else {
-	$r->print(&Apache::loncommon::start_page('Construction Space',undef));
+	$r->print(&Apache::loncommon::start_page('Construction Space',undef,
+						 { 'only_body' => 1,}));
 	$r->print($pagetitle);
     }
 
